@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-present Icinga Developer Team.
+// Copyright (c) 2009-2014 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -45,16 +45,22 @@ class Api_ApiCommandAction extends IcingaApiBaseAction {
         $command = $rd->getParameter("command");
         
         $targets = json_decode($rd->getParameter("target"),true);
+
         $data = json_decode($rd->getParameter("data"),true);
 
+        if (!is_array($data)) {
+            $this->setAttribute('error', 'Parameter data={} could not decoded from json');
+            return 'Error';
+        }
+
         if (!is_array($targets)) {
             $targets = array($targets);
         }
 
         $api = $this->getContext()->getModel("System.CommandSender","Cronks");
         $api->setCommandName($command);
-        
-        $api->setData(array_merge($data,array("data"=>$data)));
+
+        $api->setData($data);
         $api->setSelection($targets);
         
         // send it
