@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-present Icinga Developer Team.
+// Copyright (c) 2009-2014 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -90,27 +90,44 @@ class Api_Commands_CommandDispatcherModel extends IcingaApiBaseModel implements
 
     private function buildCommandString(array $command, array $params) {
         $str = "[".time()."] ".$command["definition"];
+
         foreach($command["parameters"] as $param=>$vals) {
             if(!isset($vals["required"]))
                 $vals["required"] = true;
 
+            /*
+             * Use default values if any
+             */
+            if (!isset($params[$vals["alias"]]) && $vals["required"] && array_key_exists('defaultValue', $vals)) {
+                $params[$vals["alias"]] = $vals['defaultValue'];
+            }
+
             if (!isset($params[$vals["alias"]]) && $vals["required"]) {
                 throw new MissingCommandParameterException($vals["alias"]." is missing");
             } else if (!isset($params[$vals["alias"]])) {
                 $str .= ";";
             } else {
                 $val = ($params[$vals["alias"]]);
-                $val = preg_replace("/\n/"," ",$val);
-                    
-                switch ($vals["type"]) {
-                    case "date":
-                        $val = strtotime($val);
-                        break;
+
+                /*
+                 * Sanitize data to not break the whole command chain
+                 */
+                if (is_array($val) == true) {
+                    $val = '';
+                } else {
+                    $val = preg_replace("/\n/"," ",$val);
+
+                    switch ($vals["type"]) {
+                        case "date":
+                            $val = strtotime($val);
+                            break;
+                    }
                 }
+
                 // Perfdata is a a special case that requires | instead of ;
-                if($param != "COMMAND_PERFDATA")
+                if($param != "COMMAND_PERFDATA") {
                     $str .= ";".$val;
-                else {
+                } else {
                     if(trim($val) != "")
                         $str .= "|".$val;
                 }
