@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-present Icinga Developer Team.
+// Copyright (c) 2009-2014 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -170,11 +170,34 @@ class AppKitDoctrineSessionStorage extends AgaviSessionStorage {
      * @param mixed $data
      */
     public function sessionWrite($id, &$data) {
-        AppKitLogger::verbose("Writing new session information (checksum=%s)",md5($data));
+        $max = ini_get('session.gc_maxlifetime');
+        $update = false;
+
+        if (! $max) {
+            $max = 1440;
+        }
+
+        $date = DateTime::createFromFormat('Y-m-d H:i:s', $this->NsmSession->session_modified);
+        $m = md5($data);
+
+        if ($date === false || (time() - $date->getTimestamp()) >= $max) {
+            $update = true;
+        }
+
+        if (! $update && $this->NsmSession->session_checksum === $m) {
+            return;
+        }
+
+        AppKitLogger::verbose("Writing new session information (checksum=%s)", $m);
+
         $this->NsmSession->session_data = $data;
-        $this->NsmSession->session_checksum = md5($data);
+        $this->NsmSession->session_checksum = $m;
         $this->NsmSession->session_modified = date('Y-m-d H:i:s');
+
         $this->NsmSession->save();
+
+        AppKitLogger::debug("Write session update: %s", $id);
+
         AppKitLogger::verbose("Writing new session information successful");
     }
 
