@@ -2,7 +2,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2012 Icinga Developer Team.
+// Copyright (c) 2009-2014 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -39,10 +39,11 @@ Ext.ns("Cronk.grid");
         loadMask: true,
         collapsible: false,
         animCollapse: true,
+        unstyled: true,
         border: false,
         emptyText: _("No data was found"),
         layout: 'fit',
-        baseCls: 'icinga-metagrid', // Allow style moifications
+        //baseCls: 'icinga-metagrid', // Allow style moifications
 
         selectedConnection: 'icinga',
 
@@ -168,6 +169,7 @@ Ext.ns("Cronk.grid");
             
             this.fieldIterator(function (fieldName, field) {
                 if (field.order['default'] === true) {
+                    field.order.order = field.order.order || field.order.direction;
                     storeConfig.sortInfo = {
                         direction: (field.order.order ? field.order.order.toUpperCase() : 'ASC'),
                         field: fieldName
@@ -457,7 +459,7 @@ Ext.ns("Cronk.grid");
         getView: function () {
             if (!this.view) {
                 var viewConfig = {
-                    forceFit: true,
+                    forceFit: false,
                     groupTextTpl: '{text} ({[values.rs.length]}' + ' {[values.rs.length > 1 ? "Items" : "Item"]})'
                 };
 
@@ -501,7 +503,15 @@ Ext.ns("Cronk.grid");
                     store: this.getStore(),
                     displayInfo: true,
                     displayMsg: _('Displaying topics {0} - {1} of {2}'),
-                    emptyMsg: _('No topics to display')
+                    emptyMsg: _('No topics to display'),
+                    listeners: {
+                        change: function() {
+                            var sm = this.getSelectionModel();
+                            if (sm && typeof sm.syncWithPage === 'function')
+                                sm.syncWithPage();
+                        },
+                        scope: this
+                    }
                 };
 
                 if (Ext.isEmpty(datasource.countmode) || datasource.countmode === "none") {
@@ -530,7 +540,7 @@ Ext.ns("Cronk.grid");
                     iconCls: 'icinga-icon-arrow-refresh',
                     tooltip: _('Refresh the data in the grid'),
                     handler: function (oBtn, e) {
-                        this.store.load();
+                        this.store.reload();
                     },
                     scope: this
                 }, {
@@ -557,6 +567,7 @@ Ext.ns("Cronk.grid");
                                         btn.setChecked(v, true);
                                     });
                                 },
+
                                 scope: this
 
                             },
@@ -594,6 +605,15 @@ Ext.ns("Cronk.grid");
                                 });
                             },
                             scope: this
+                        }, {
+                            // Fixes #3432
+                            text: _('Reset grid action icons'),
+                            iconCls: 'icinga-icon-bin',
+                            scope: this,
+                            handler: function(button, event) {
+                                var actionPanel = this.rowActionPanel.getPanel();
+                                actionPanel.removeAllOverrides();
+                            }
                         }]
                     }
                 }],
@@ -618,7 +638,7 @@ Ext.ns("Cronk.grid");
             var options = this.getOption("template.option", {});
             if (!Ext.isEmpty(options.selection_model)) {
                 if (options.selection_model === "checkbox") {
-                    var sm = new Ext.grid.CheckboxSelectionModel({
+                    var sm = new Cronk.grid.ObjectSelectionModel({
                         dataIndex: "id"
                     });
 
@@ -659,40 +679,43 @@ Ext.ns("Cronk.grid");
             });
 
             if (filters.length) {
-                var fw = new Cronk.grid.filter.Window();
 
-                fw.setGrid(this);
-                fw.setFilterCfg(filters);
-
-                // Distribute destroy events
-                this.on('destroy', function () {
-                    fw.destroyHandler();
-                });
-
-                this.on('refresh', function () {
-                    fw.destroyHandler();
-                });
-
-                this.topToolbar.add(['-', {
-                    text: _("Filter"),
+                // Button is extracted from creation because we need it
+                // on the filter window to mark active state #3928
+                var btn = Ext.create({
+                    xtype: 'button',
+                    text: _('View filter'),
                     iconCls: 'icinga-icon-pencil',
-                    id: this.id + "_filterBtn",
-                    menu: {
-                        items: [{
-                            text: _("Modify"),
-                            iconCls: 'icinga-icon-application-form',
-                            handler: fw.startHandler,
-                            scope: this
-                        }, {
-                            text: _("Remove"),
-                            iconCls: 'icinga-icon-cancel',
-                            handler: function (b, e) {
-                                fw.removeFilters();
-                            },
-                            scope: this
-                        }]
-                    }
-                }]);
+                    id: this.id+'_viewFilterBtn',
+                    handler: function(cmp,state) {
+                        Ext.getCmp('west-frame').resetCronkView();
+                        // update filter window with current filter
+                        if(this.store.baseParams.filter_json && this.store.baseParams.filter_json != 'null')
+                            this.filterHdl.updateFromJsonString(this.store.baseParams.filter_json);
+                        this.filterHdl.show();
+                    },
+                    scope: this
+                });
+
+                this.filterHdl = new Icinga.Cronks.util.FilterEditorWindow(this, filters, btn);
+
+                this.topToolbar.add(['-', btn]);
+                this.topToolbarFilterPos = this.topToolbar.items.length;
+            }
+        },
+
+        applyDecorators: function() {
+            var decorators = this.meta.template.decorators;
+            if(!Ext.isArray(decorators))
+                return;
+            for(var i=0;i<decorators.length;i++) {
+                var dec = (new Function("return "+decorators[i]))();
+
+                if(dec) {
+                   dec(this);
+                } else {
+                    AppKit.log("Unknown grid decorator ",decorators[i]);
+                }
             }
         },
 
@@ -777,28 +800,36 @@ Ext.ns("Cronk.grid");
             var cronk = this.ownerCt.CronkPlugin.cmpConfig;
             var urlParams = "cr_base=";
 
-
+            var jsonFilter = store.baseParams['filter_json'];
             var counter = 0;
             for (var i in store.baseParams) {
-                if (i) {
+                if (i && i != 'filter_json') {
                     var name = i.replace(/(.*?)\[(.*?)\]/g, '$1|$2_' + counter);
                     urlParams += name + "=" + store.baseParams[i] + ";";
                     counter++;
                 }
             }
 
+            urlParams += '/';
             if (store.sortInfo) {
-                urlParams += "/groupDir=" + store.sortInfo.direction + "/" + "groupField=" + store.sortInfo.field + "/";
-            } else {
-                urlParams += "/groupDir=ASC/" + "groupField=instance/";
+                if (store.groupField) {
+                    urlParams += "groupDir=" + store.sortInfo.direction + "/";
+                    urlParams += "groupField=" + store.sortInfo.field + "/";
+                } else {
+                    urlParams += "sortDir=" + store.sortInfo.direction + "/";
+                    urlParams += "sortField=" + store.sortInfo.field + "/";
+                }
             }
 
             if (Ext.isDefined(cronk.iconCls)) {
                 urlParams += "iconCls=" + cronk.iconCls + "/";
             }
 
-            urlParams += "template=" + this.initialConfig.meta.params.template + "/" + "crname=" + cronk.crname + "/" + "title=" + cronk.title + "/";
 
+            urlParams += "template=" + this.initialConfig.meta.params.template + "/" + "crname=" + cronk.crname + "/" + "title=" + cronk.title + "/";
+            if (Ext.isDefined(jsonFilter)) {
+                urlParams += "?filter=" + jsonFilter;
+            }
             return urlParams;
         },
 
@@ -818,7 +849,9 @@ Ext.ns("Cronk.grid");
                     }
                 }
             }, this);
-
+            this.store.on("load",function() {
+                this.saveState();
+            },this)
             this.on("show", function () {
                 if (this.autoRefreshEnabled) {
                     this.startRefreshTimer();
@@ -837,6 +870,10 @@ Ext.ns("Cronk.grid");
                     msg: _("Loading ...")
                 });
             }, this);
+
+            this.on("columnmove", function(grid) {
+                this.saveState();
+            }, this);
         },
 
         /**
@@ -970,7 +1007,9 @@ Ext.ns("Cronk.grid");
          * refresh our grid data
          *  @private
          */
-        refreshTask: new Ext.util.DelayedTask(function () {
+        refreshTask: null, // not creating the singleton here
+
+        refreshTaskImpl: function () {
             //NOTE: hidden tabs won't be refreshed
             if (!this.store || this.ownerCt.hidden) {
                 return true;
@@ -982,12 +1021,15 @@ Ext.ns("Cronk.grid");
             } else if (this.getStore()) {
                 this.getStore().reload();
             }
-        }),
+        },
 
         /**
          * Calls the refreshTask 200ms delayed
          */
         refreshGrid: function () {
+            // create the refreshTask for this MetaGridPanel
+            if (!this.refreshTask)
+                this.refreshTask = new Ext.util.DelayedTask(this.refreshTaskImpl);
             this.refreshTask.delay(200, null, this);
         },
 
@@ -998,7 +1040,7 @@ Ext.ns("Cronk.grid");
         getState: function () {
             var store = this.getStore();
             var aR = null;
-            
+
             if (this.autoRefreshEnabled === true) {
                 aR = 1;
             }
@@ -1006,11 +1048,12 @@ Ext.ns("Cronk.grid");
             if (this.autoRefreshEnabled === false) {
                 aR = -1;
             }
-            
+
             var o = {
-                nativeState: Ext.grid.GridPanel.prototype.getState.apply(this),
                 filter_params: this.filter_params || {},
                 filter_types: this.filter_types || {},
+                filter: this.store.baseParams.filter_json,
+                nativeState: Ext.grid.GridPanel.prototype.getState.apply(this),
                 store_origin_params: ("originParams" in store) ? store.originParams : {},
                 sortToggle: store.sortToggle,
                 sortInfo: store.sortInfo,
@@ -1018,7 +1061,7 @@ Ext.ns("Cronk.grid");
                 autoRefresh: aR,
                 connection: this.store.baseParams.connection
             };
-            
+
             return o;
         },
 
@@ -1031,12 +1074,15 @@ Ext.ns("Cronk.grid");
             if (!Ext.isObject(state)) {
                 return false;
             }
-
             var reload = false;
             var store = this.getStore();
             if (Ext.isObject(state.colModel)) {
                 this.applyPersistentColumnModel(state.colModel);
             }
+            if (state.filter) {
+                this.filterHdl.updateFromJsonString(state.filter);
+                this.store.setBaseParam("filter_json",state.filter);
+            }
 
             if (state.filter_types) {
                 this.filter_types = state.filter_types;
@@ -1076,7 +1122,6 @@ Ext.ns("Cronk.grid");
 
             if (state.connection) {
                 this.setConnection(state.connection);
-
             }
             if (Ext.isObject(state.nativeState)) {
                 return Ext.grid.GridPanel.prototype.applyState.call(this, {
@@ -1190,10 +1235,12 @@ Ext.ns("Cronk.grid");
             if (!Ext.isEmpty(this.parameters.autoRefresh)) {
                 this.startRefreshTimer();
             }
-
+            this.applyDecorators();
             if (this.getOption("template.option.mode") === "minimal") {
                 this.topToolbar.hide();
             }
+
+
         }
 
     });
@@ -1203,4 +1250,4 @@ Ext.ns("Cronk.grid");
      */
     Ext.reg('cronkgrid', Cronk.grid.MetaGridPanel);
 
-})();
\ No newline at end of file
+})();
