@@ -2,7 +2,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2012 Icinga Developer Team.
+// Copyright (c) 2009-2014 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -129,28 +129,37 @@ Ext.ns('Cronk.util');
                                 var i = 0;
 
                                 Ext.iterate(oGrid.filter_types, function (key, item) {
-                                    var r = new Ext.data.Record(item);
 
-                                    selectRestrictionHandler(oCombo, r, i);
+                                    // New format (since 1.7.0)
+                                    if (Ext.isEmpty(item['fType'])) {
+                                        var r = new Ext.data.Record(item);
+                                        selectRestrictionHandler(oCombo, r, i);
+
+                                    // Old format, 1.6 versions
+                                    } else {
+                                        var searchId = item['fType'];
+                                        var record = oCombo.getStore().getById(searchId);
+                                        if (record) {
+                                            selectRestrictionHandler(oCombo, record, i);
+                                        }
+                                    }
                                     i++;
                                 });
                             }
 
                             if (oGrid.filter_params && oCoPanel) {
                                 Ext.iterate(oGrid.filter_params, function (key, val) {
-                                    //                              console.log(key + ": " + val);
                                     key = key.replace(/^f\[|\]$/g, "");
                                     var c = oCoPanel.findBy(function (ti) {
-
-                                        if (ti.hiddenName === key || ti.name === key) {
-                                            return true;
-                                        }
-
-                                        return false;
+                                        return ti.hiddenName === key || ti.name === key;
                                     });
 
                                     if (c[0]) {
-                                        c[0].setValue(val);
+                                        // Set value as String (cause of ===)
+                                        // and after component is rendered ready
+                                        c[0].on('afterrender', function() {
+                                            c[0].setValue(String(val));
+                                        }, c[0], {single:true});
                                     }
                                 });
                             }
@@ -488,7 +497,6 @@ Ext.ns('Cronk.util');
              */
             applyFilters: function (owd) {
                 var data = owd || getFormValues();
-
                 oGrid.getStore().baseParams = {};
                 Ext.apply(oGrid.getStore().baseParams, oOrgBaseParams);
                 Ext.apply(oGrid.getStore().baseParams, data);
