@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2012 Icinga Developer Team.
+// Copyright (c) 2009-2014 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -100,9 +100,11 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         }
         
         $this->initializeXmlData();
-        
-        $this->cronks = $this->getCronks(true);
-        
+
+        if (!isset($parameters['lazy'])) {
+            $this->cronks = $this->getCronks(true);
+        }
+
     }
     
     /**
@@ -225,8 +227,22 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
      * @return array
      */
     private function getXmlCronks($all=false) {
-        $out = array();
+        // pull cronk xml data from the cache
+        $cached = $this->user->getStorage()->read("icinga.cronks.cache.xml");
 
+        // get me a timestamp for our xml disk cache for cronks
+        $configcache_ts = filemtime(AgaviConfigCache::checkConfig(AgaviConfig::get('core.config_dir'). '/cronks.xml'));
+
+        // do we have any cache?
+        if(isset($cached) and isset($cached["data"])) {
+            // is the cached data newer than that in the xml cache on disk?
+            if(isset($cached["timestamp"]) and $cached["timestamp"] > $configcache_ts) {
+                // return cache
+                return $cached["data"];
+            }
+        }
+
+        $out = array();
         foreach(self::$xml_cronk_data as $uid=>$cronk) {
             
             /*
@@ -250,14 +266,16 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
             elseif(isset($cronk['disabled']) && $cronk['disabled'] == true) {
                 continue;
             }
+            /* ignoring all here - because the cache needs all cronks! -mfrosch
             elseif($all == false && isset($cronk['hide']) && $cronk['hide'] == true) {
                 continue;
             }
+            */
             elseif(!isset($cronk['action']) || !isset($cronk['module'])) {
                 $this->getContext()->getLoggerManager()->log('No action or module for cronk: '. $uid, AgaviLogger::ERROR);
                 continue;
             }
-            
+
             $out[$uid] = array(
                 'cronkid' => $uid,
                 'module' => $cronk['module'],
@@ -276,9 +294,11 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
                 'position' => isset($cronk['position']) ? $cronk['position'] : 0,
                 'owner_name' => self::DEFAULT_CRONK_OWNER,
                 'owner_id' => self::DEFAULT_CRONK_OWNERID
-                         );
+            );
+
         }
-        
+        // write data to the cache, with a timestamp
+        $this->user->getStorage()->write("icinga.cronks.cache.xml",array("timestamp" => time(), "data" => $out));
         return $out;
     }
 
@@ -383,7 +403,6 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         $cronks = (array)$this->getDbCronks() + $cronks;
 
         $this->reorderCronks($cronks);
-
         return $cronks;
     }
     
@@ -680,13 +699,17 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         $cronks_out = array();
         
         $categories = $this->getCategoryModel()->getCategories();
-        
+
         $cronks = $this->getCronks();
 
         foreach($categories as $category_name=>$category) {
             $tmp = array();
 
             foreach($cronks as $cronk) {
+                // skipping hidden cronks for the output
+                if ($cronk['hide'] == true) {
+                    continue;
+                }
                 if (AppKitArrayUtil::matchAgainstStringList($cronk['categories'], $category_name)) {
                     $tmp[] = $cronk;
                 }
