@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2013 Icinga Developer Team.
+// Copyright (c) 2009-2014 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -42,6 +42,9 @@ class IcingaDataHostgroupPrincipalTarget extends IcingaDataPrincipalTarget {
         $this->setApiMappingFields(array(
                 'hostgroup'  => 'HOSTGROUP_NAME'
         ));
+
+        $this->ornull = true;
+        $this->ornullfield = '${HOST_OBJECT_ID}';
     }
 
-}
\ No newline at end of file
+}
